@@ -473,6 +473,7 @@ gnome_scan_dialog_new (GtkWindow *parent, GnomeScanJob *job)
 									"window-position", GTK_WIN_POS_CENTER,
 									"default-width", 320,
 									"default-height", 420,
+									/* translator: this is the dialog title */
 									"title", _("Scan"),
 									"has-separator", FALSE,
 									"modal", TRUE,
@@ -511,14 +512,14 @@ gnome_scan_dialog_run (GnomeScanDialog *dialog)
 	
 	if (g_slist_length (priv->backends) == 0) {
 		gsd_message_dialog (dialog, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
-							_("Unable to detect scanners !"),
+							_("Unable to detect scanners!"),
 							_("No drivers has been found."));
 		return;
 	}
 	
 	if (priv->probe_done && !priv->scanner_count) {
 		gsd_message_dialog (dialog, GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
-							_("No device found !"),
+							_("No device found!"),
 							_("Ensure your device is plugged, powered, supported and configured. "
 							  "The dialog will run until you plug a scanner or cancel."));
 	}
@@ -650,7 +651,7 @@ gsd_build_group_box (GnomeScanDialog *dialog, GtkWidget *page, GtkBox *box, Gnom
 			label = NULL;
 		}
 		else {
-			label = gtk_label_new (g_strdup_printf (_("%s:"),
+			label = gtk_label_new (g_strdup_printf ("%s:",
 													dgettext (gs_param_spec_get_domain (node->data),
 															  g_param_spec_get_nick (node->data))));
 			gtk_misc_set_alignment (GTK_MISC (label), 0., .5);
@@ -892,7 +893,7 @@ gsd_probe_done (GnomeScanBackend *backend, GnomeScanDialog *dialog)
 	}
 
 	if (priv->probe_done) {
-		arrow_cursor = gdk_cursor_new(GDK_ARROW);
+		arrow_cursor = gdk_cursor_new(GDK_LEFT_PTR);
 		gdk_window_set_cursor (GTK_WIDGET(dialog)->window,
 							   arrow_cursor);
 		gdk_cursor_unref (arrow_cursor);
@@ -1389,6 +1390,7 @@ gsd_build_preview_ui (GnomeScanDialog *gsd)
 	priv->preview_stage = gtk_label_new (NULL);
 	gtk_misc_set_alignment (GTK_MISC (priv->preview_stage), 0., .5);
 	gtk_label_set_markup (GTK_LABEL (priv->preview_stage),
+						  /* translator: initial state before preview begin. */
 						  g_strconcat("<i>", _("Inactive"), "</i>", NULL));
 	gtk_box_pack_start (GTK_BOX (box), priv->preview_stage, FALSE, FALSE, 0);
 	
